package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.RSAPublicKeyStructure;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.crypto.params.RSAKeyParameters;
import java.io.IOException;
import java.math.BigInteger;
import java.security.interfaces.RSAPublicKey;
import java.security.spec.RSAPublicKeySpec;

public class JCERSAPublicKey implements RSAPublicKey {
   static final long serialVersionUID = 2675817738516720772L;
   private BigInteger modulus;
   private BigInteger publicExponent;

   JCERSAPublicKey(RSAKeyParameters key) {
      this.modulus = key.getModulus();
      this.publicExponent = key.getExponent();
   }

   JCERSAPublicKey(RSAPublicKeySpec spec) {
      this.modulus = spec.getModulus();
      this.publicExponent = spec.getPublicExponent();
   }

   JCERSAPublicKey(RSAPublicKey key) {
      this.modulus = key.getModulus();
      this.publicExponent = key.getPublicExponent();
   }

   JCERSAPublicKey(SubjectPublicKeyInfo info) {
      JCERSAPublicKey var10000 = this;
      JCERSAPublicKey var10001 = this;
      super();

      RSAPublicKeyStructure var10002;
      boolean var5;
      try {
         var10002 = new RSAPublicKeyStructure;
      } catch (IOException var3) {
         var5 = false;
         throw new IllegalArgumentException("invalid info structure in RSA public key");
      }

      RSAPublicKeyStructure var4;
      RSAPublicKeyStructure var10003 = var4 = var10002;

      try {
         var10003.<init>((ASN1Sequence)info.getPublicKey());
         var10001.modulus = var10002.getModulus();
         var10000.publicExponent = var4.getPublicExponent();
      } catch (IOException var2) {
         var5 = false;
         throw new IllegalArgumentException("invalid info structure in RSA public key");
      }
   }

   public BigInteger getModulus() {
      return this.modulus;
   }

   public BigInteger getPublicExponent() {
      return this.publicExponent;
   }

   public String getAlgorithm() {
      return "RSA";
   }

   public String getFormat() {
      return "X.509";
   }

   public byte[] getEncoded() {
      AlgorithmIdentifier var10002 = new AlgorithmIdentifier(PKCSObjectIdentifiers.rsaEncryption, new DERNull());
      JCERSAPublicKey var10005 = this;
      BigInteger var1 = this.getModulus();
      return (new SubjectPublicKeyInfo(var10002, (new RSAPublicKeyStructure(var1, var10005.getPublicExponent())).getDERObject())).getDEREncoded();
   }

   public int hashCode() {
      return this.getModulus().hashCode() ^ this.getPublicExponent().hashCode();
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof RSAPublicKey)) {
         return false;
      } else {
         RSAPublicKey o1 = (RSAPublicKey)o;
         return this.getModulus().equals(o1.getModulus()) && this.getPublicExponent().equals(o1.getPublicExponent());
      }
   }

   public String toString() {
      StringBuffer var10000 = new StringBuffer();
      String var1 = System.getProperty("line.separator");
      var10000.append("RSA Public Key").append(var1);
      var10000.append("            modulus: ").append(this.getModulus().toString(16)).append(var1);
      var10000.append("    public exponent: ").append(this.getPublicExponent().toString(16)).append(var1);
      return var10000.toString();
   }
}
